var my_data = setOf<String>(
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
)
my_data = setOf<String>(
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
)
