class Check {
    public static void check() {
var my_data = new Object[]{
    true,
    "hi",
    new int[]{1, 2},
    null
};
my_data = new Object[]{
    true,
    "hi",
    new int[]{1, 2},
    null
};
    }
}
