package main

func main() {
my_data := []map[string]any{
    {"name": "Alice", "age": 30},
    {"name": "Bob", "age": 25},
}
my_data = []map[string]any{
    {"name": "Alice", "age": 30},
    {"name": "Bob", "age": 25},
}
_ = my_data
}
