Imports System.Collections.Generic
Module Check
    Sub _declaration()
        Dim my_data = New Object() {
            New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_1"}, {"draft", True}},
            New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_2"}}
        }
    End Sub
    Sub _assignment()
        Dim my_data As Object
        my_data = New Object() {
            New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_1"}, {"draft", True}},
            New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_2"}}
        }
    End Sub
End Module
