my_data = {
    struct('type', "create", 'pr_id', "pr_1", 'draft', true),
    struct('type', "create", 'pr_id', "pr_2")
};
my_data = {
    struct('type', "create", 'pr_id', "pr_1", 'draft', true),
    struct('type', "create", 'pr_id', "pr_2")
};
