#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    @[@{@"name": @"Alice"}, @{@"name": @"Bob"}],
    @[@{@"name": @"Charlie"}, @{@"name": @"Dave"}],
];
my_data = @[
    @[@{@"name": @"Alice"}, @{@"name": @"Bob"}],
    @[@{@"name": @"Charlie"}, @{@"name": @"Dave"}],
];
    (void)my_data;
}
