my_data = {
    {struct('name', "Alice"), struct('name', "Bob")},
    {struct('name', "Charlie"), struct('name', "Dave")}
};
my_data = {
    {struct('name', "Alice"), struct('name', "Bob")},
    {struct('name', "Charlie"), struct('name', "Dave")}
};
