IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 F-KEY PIC X(23) VALUE "value "" # not a comment".  *> real
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
