import datetime
my_data = datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=45, microsecond=123456)
my_data = datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=45, microsecond=123456)
