var my_data = mapOf<String, Any?>(
    // Server configuration
    "host" to "localhost",  // default host
    "port" to 8080,
    // Enable debug mode
    "debug" to true,
)
my_data = mapOf<String, Any?>(
    // Server configuration
    "host" to "localhost",  // default host
    "port" to 8080,
    // Enable debug mode
    "debug" to true,
)
