object Check {
var my_data = List[Map[String, Any]](
    Map("type" -> "create", "pr_id" -> "pr_1", "draft" -> true),
    Map("type" -> "create", "pr_id" -> "pr_2"),
)
my_data = List[Map[String, Any]](
    Map("type" -> "create", "pr_id" -> "pr_1", "draft" -> true),
    Map("type" -> "create", "pr_id" -> "pr_2"),
)
}
