var my_data = mapOf<String, Any?>(
    "name" to "Alice",
    "age" to 30,
    "active" to true,
    "score" to null,
)
my_data = mapOf<String, Any?>(
    "name" to "Alice",
    "age" to 30,
    "active" to true,
    "score" to null,
)
