package main

func main() {
my_data := map[any]struct{}{
    true: struct{}{},
    42: struct{}{},
    "apple": struct{}{},
}
my_data = map[any]struct{}{
    true: struct{}{},
    42: struct{}{},
    "apple": struct{}{},
}
_ = my_data
}
