IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER COMP-2 VALUE 1.1.
    05 FILLER COMP-2 VALUE 2.2.
    05 FILLER COMP-2 VALUE 3.3.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
