IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(10) VALUE "2024-01-15".
    05 FILLER PIC X(10) VALUE "2024-02-20".
PROCEDURE DIVISION.
    STOP RUN.
