object Check {
var my_data = List[String](
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
)
my_data = List[String](
    "C:\\path\\to\\file",
    "back\\\\slash",
    "hello \\\"world\\\"",
)
}
