use DateTime;
my $my_data = [
    DateTime->new(year => 2024, month => 1, day => 15, hour => 12, minute => 30, second => 0, nanosecond => 123456000, time_zone => 'UTC'),
    DateTime->new(year => 2024, month => 6, day => 1, hour => 8, minute => 0, second => 0, time_zone => 'UTC'),
];
