IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(32) VALUE "2024-01-15T12:30:00.123456+00:00".
    05 FILLER PIC X(25) VALUE "2024-06-01T08:00:00+00:00".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
