IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(1) VALUE "a".
    *> trailing
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
