import Foundation
var my_data: Any = DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15).date!
my_data = DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15).date!
