import java.util.Set;
class Check {
    public static void check() {
var my_data = Set.of(
    "apple",  // inline comment
    // before banana
    "banana"
    // trailing
);
my_data = Set.of(
    "apple",  // inline comment
    // before banana
    "banana"
    // trailing
);
    }
}
