use DateTime;
my $my_data = [
    DateTime->new(year => 2024, month => 1, day => 15),
    DateTime->new(year => 2024, month => 6, day => 1),
];
$my_data = [
    DateTime->new(year => 2024, month => 1, day => 15),
    DateTime->new(year => 2024, month => 6, day => 1),
];
