my_data = [
    Dict("first" => "Alice", "last" => "Smith"),
    Dict("first" => "Bob", "last" => "Jones"),
]
my_data = [
    Dict("first" => "Alice", "last" => "Smith"),
    Dict("first" => "Bob", "last" => "Jones"),
]
