import java.time.LocalDate;
class Check {
    public static void check() {
var my_data = new LocalDate[]{
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 2, 20)
};
my_data = new LocalDate[]{
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 2, 20)
};
    }
}
