var my_data = setOf<String>(
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
)
my_data = setOf<String>(
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
)
