import java.util.HashMap;
import java.util.Map;
class Check {
    public static void check() {
var my_data = new HashMap<>(Map.ofEntries(
    Map.entry("name", "Alice"),
    Map.entry("scores", new int[]{10, 20, 30})
));
    }
}
