import java.time.LocalDate
object Check {
var my_data = Set[LocalDate](
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1),
)
my_data = Set[LocalDate](
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1),
)
}
