IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 FILLER.
15 FILLER PIC S9(18) COMP-5 VALUE 1.
15 FILLER PIC S9(18) COMP-5 VALUE 2.
10 FILLER.
15 FILLER PIC S9(18) COMP-5 VALUE 3.
15 FILLER PIC S9(18) COMP-5 VALUE 4.
    05 FILLER PIC S9(18) COMP-5 VALUE 5.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
