#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    @"name": @"Alice",
    @"scores": @[@(10), @(20), @(30)],
};
my_data = @{
    @"name": @"Alice",
    @"scores": @[@(10), @(20), @(30)],
};
    (void)my_data;
}
