use DateTime;
my $my_data = {
    "name" => "Alice",
    "age" => 30,
    "active" => 1,
    "score" => undef,
    "joined" => DateTime->new(year => 2024, month => 1, day => 15),
    "last_login" => DateTime->new(year => 2024, month => 1, day => 15, hour => 12, minute => 30, second => 0, time_zone => 'UTC'),
    "avatar" => "48656c6c6f",
};
$my_data = {
    "name" => "Alice",
    "age" => 30,
    "active" => 1,
    "score" => undef,
    "joined" => DateTime->new(year => 2024, month => 1, day => 15),
    "last_login" => DateTime->new(year => 2024, month => 1, day => 15, hour => 12, minute => 30, second => 0, time_zone => 'UTC'),
    "avatar" => "48656c6c6f",
};
