#include <initializer_list>
#include <string>
#include <map>
#include <vector>
struct _Any {
    template<class T> _Any(T&&) noexcept {}
    _Any(std::initializer_list<_Any>) noexcept {}
};
void _check() {
_Any my_data = std::vector<std::map<std::string, double>>{
    std::map<std::string, double>{{"x", 1}, {"y", 2.5}},
    std::map<std::string, double>{{"x", 3}, {"y", 4.0}},
};
}
