final my_data = <List<Map<String, String>>>[
    <Map<String, String>>[<String, String>{"name": "Alice"}, <String, String>{"name": "Bob"}],
    <Map<String, String>>[<String, String>{"name": "Charlie"}, <String, String>{"name": "Dave"}],
];
