IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 F-NAME PIC X(5) VALUE "Alice".
    05 F-AGE PIC S9(18) COMP-5 VALUE 30.
    05 F-ACTIVE PIC X(5) VALUE "TRUE".
    05 F-SCORE PIC X(1) VALUE SPACES.
    05 F-JOINED PIC X(10) VALUE "2024-01-15".
    05 F-LAST-LOGIN PIC X(25) VALUE "2024-01-15T12:30:00+00:00".
    05 F-AVATAR PIC X(10) VALUE "48656c6c6f".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
