using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    ["a"] = new Dictionary<string, int> {["x"] = 1},
    ["b"] = 2
};
my_data = new Dictionary<string, object> {
    ["a"] = new Dictionary<string, int> {["x"] = 1},
    ["b"] = 2
};
