IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 F-FIRST PIC X(5) VALUE "Alice".
10 F-LAST PIC X(5) VALUE "Smith".
    05 FILLER.
10 F-FIRST PIC X(3) VALUE "Bob".
10 F-LAST PIC X(5) VALUE "Jones".
PROCEDURE DIVISION.
    STOP RUN.
