import std.json;
void _check() {
auto my_data = JSONValue([
    // first
    JSONValue("a"),
    // second
    JSONValue("b"),
]);
my_data = JSONValue([
    // first
    JSONValue("a"),
    // second
    JSONValue("b"),
]);
}
