fn main() {
    {
        let my_data = vec![
            // first
            "a",
            // second
            "b",
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        // first
        "a",
        // second
        "b",
    ];
    let _ = my_data;
}
