var my_data: Any = Set<AnyHashable>([
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
])
my_data = Set<AnyHashable>([
    "apple",  // inline comment
    // before banana
    "banana",
    // trailing
])
