#lang racket
(define my_data (list
    (hash "first" "Alice" "last" "Smith")
    (hash "first" "Bob" "last" "Jones")
))
(set! my_data (list
    (hash "first" "Alice" "last" "Smith")
    (hash "first" "Bob" "last" "Jones")
))
