var my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("x" to 1, "y" to 2.5),
    mapOf<String, Any?>("x" to 3, "y" to 4.0),
)
my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("x" to 1, "y" to 2.5),
    mapOf<String, Any?>("x" to 3, "y" to 4.0),
)
