class Check {
    public static void check() {
var my_data = new Object[]{
    new Object[]{1, "a"},
    new Object[]{2, "b"}
};
my_data = new Object[]{
    new Object[]{1, "a"},
    new Object[]{2, "b"}
};
    }
}
