using System.Collections.Generic;
using System;
var my_data = (
    new Dictionary<string, string> {["first"] = "Alice", ["last"] = "Smith"},
    new Dictionary<string, string> {["first"] = "Bob", ["last"] = "Jones"}
);
