my_data <- list(
    list("first" = "Alice", "last" = "Smith"),
    list("first" = "Bob", "last" = "Jones")
)
my_data <- list(
    list("first" = "Alice", "last" = "Smith"),
    list("first" = "Bob", "last" = "Jones")
)
