package main

func main() {
my_data := [][]map[string]string{
    []map[string]string{{"name": "Alice"}, {"name": "Bob"}},
    []map[string]string{{"name": "Charlie"}, {"name": "Dave"}},
}
my_data = [][]map[string]string{
    []map[string]string{{"name": "Alice"}, {"name": "Bob"}},
    []map[string]string{{"name": "Charlie"}, {"name": "Dave"}},
}
_ = my_data
}
