import java.time.LocalDate;
import java.util.Set;
class Check {
    public static void check() {
var my_data = Set.of(
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1)
);
my_data = Set.of(
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1)
);
    }
}
