import std.json;
void _check() {
auto my_data = JSONValue([
    JSONValue(1000000),
    JSONValue(-1234),
    JSONValue(255),
    JSONValue(-10),
]);
my_data = JSONValue([
    JSONValue(1000000),
    JSONValue(-1234),
    JSONValue(255),
    JSONValue(-10),
]);
}
