#lang racket
(define my_data (hash
    ; Configuration
    "name" "app"
    ; Port setting
    "port" 3000
))
(set! my_data (hash
    ; Configuration
    "name" "app"
    ; Port setting
    "port" 3000
))
