var my_data: Any = Set<AnyHashable>([
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
])
my_data = Set<AnyHashable>([
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
])
