package main

func main() {
my_data := map[string]any{
    "name": "Alice",
    "scores": []int{10, 20, 30},
}
my_data = map[string]any{
    "name": "Alice",
    "scores": []int{10, 20, 30},
}
_ = my_data
}
