package main
import "time"

func main() {
my_data := []time.Time{
    time.Date(2024, time.January, 15, 0, 0, 0, 0, time.UTC),
    time.Date(2024, time.February, 20, 0, 0, 0, 0, time.UTC),
}
_ = my_data
}
