(def my_data [
    {"type" "create" "pr_id" "pr_1" "draft" true}
    {"type" "create" "pr_id" "pr_2"}
])
(def my_data [
    {"type" "create" "pr_id" "pr_1" "draft" true}
    {"type" "create" "pr_id" "pr_2"}
])
