import std.json;
void _check() {
auto my_data = JSONValue([
    JSONValue("a"),  // note a
    JSONValue("b"),  // note b
]);
my_data = JSONValue([
    JSONValue("a"),  // note a
    JSONValue("b"),  // note b
]);
}
