#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    @{@"first": @"Alice", @"last": @"Smith"},
    @{@"first": @"Bob", @"last": @"Jones"},
];
my_data = @[
    @{@"first": @"Alice", @"last": @"Smith"},
    @{@"first": @"Bob", @"last": @"Jones"},
];
    (void)my_data;
}
