using System.Collections.Generic;
using System;
var my_data = (
    (new Dictionary<string, string> {["name"] = "Alice"}, new Dictionary<string, string> {["name"] = "Bob"}),
    (new Dictionary<string, string> {["name"] = "Charlie"}, new Dictionary<string, string> {["name"] = "Dave"})
);
