import java.util.Map;
class Check {
    public static void check() {
var my_data = new Object[]{
    Map.ofEntries(Map.entry("x", 1), Map.entry("y", 2.5)),
    Map.ofEntries(Map.entry("x", 3), Map.entry("y", 4.0))
};
    }
}
