IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    *> Configuration
    05 F-NAME PIC X(3) VALUE "app".
    *> Port setting
    05 F-PORT PIC S9(18) COMP-5 VALUE 3000.
PROCEDURE DIVISION.
    STOP RUN.
