class Check {
    public static void check() {
var my_data = new String[]{
    "line1\r\nline2",
    "line1\rline2",
    ""
};
my_data = new String[]{
    "line1\r\nline2",
    "line1\rline2",
    ""
};
    }
}
