var my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("key" to "hello   world", "value" to 1),
)
my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("key" to "hello   world", "value" to 1),
)
