import java.util.Map;
class Check {
    public static void check() {
var my_data = new Object[]{
    Map.ofEntries(),
    Map.ofEntries()
};
my_data = new Object[]{
    Map.ofEntries(),
    Map.ofEntries()
};
    }
}
