#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    // first
    @"a",
    // second
    @"b",
];
my_data = @[
    // first
    @"a",
    // second
    @"b",
];
    (void)my_data;
}
