object Check {
var my_data = List[Map[String, Any]](
    Map("name" -> "Alice", "age" -> 30),
    Map("name" -> "Bob", "age" -> 25),
)
my_data = List[Map[String, Any]](
    Map("name" -> "Alice", "age" -> 30),
    Map("name" -> "Bob", "age" -> 25),
)
}
