Imports System.Collections.Generic
Module Check
    Dim my_data = New Object() {
        New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_1"}, {"draft", True}},
        New Dictionary(Of String, Object) From {{"type", "create"}, {"pr_id", "pr_2"}}
    }
End Module
