var my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("type" to "create", "pr_id" to "pr_1", "draft" to true),
    mapOf<String, Any?>("type" to "create", "pr_id" to "pr_2"),
)
my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("type" to "create", "pr_id" to "pr_1", "draft" to true),
    mapOf<String, Any?>("type" to "create", "pr_id" to "pr_2"),
)
