my_data = (
    ({"name": "Alice"}, {"name": "Bob"}),
    ({"name": "Charlie"}, {"name": "Dave"}),
)
my_data = (
    ({"name": "Alice"}, {"name": "Bob"}),
    ({"name": "Charlie"}, {"name": "Dave"}),
)
