Imports System.Collections.Generic
Module Check
    ' Configuration
    ' Port setting
    Dim my_data = New Dictionary(Of String, Object) From {
        {"name", "app"},
        {"port", 3000}
    }
End Module
