const ZVal = union(enum) {
    nil,
    bool: bool,
    int: i64,
    float: f64,
    str: []const u8,
    arr: []const ZVal,
    map: []const ZKV,
    set: []const ZVal,
};
const ZKV = struct { key: []const u8, val: ZVal };
pub fn main() void {
    const my_data: ZVal = .{ .map = &.{
        .{ .key = "name", .val = .{ .str = "Alice" } },
        .{ .key = "age", .val = .{ .int = 30 } },
        .{ .key = "active", .val = .{ .bool = true } },
        .{ .key = "score", .val = .nil },
        .{ .key = "joined", .val = .{ .int = 1705276800 } },
        .{ .key = "last_login", .val = .{ .int = 1705321800 } },
        .{ .key = "avatar", .val = .{ .str = "48656c6c6f" } },
    }};
    _ = my_data;
}
