import datetime
my_data = (
    datetime.date(year=2024, month=1, day=15),
    datetime.date(year=2024, month=2, day=20),
)
my_data = (
    datetime.date(year=2024, month=1, day=15),
    datetime.date(year=2024, month=2, day=20),
)
