import java.util.Map;
class Check {
    public static void check() {
var my_data = new Object[]{
    Map.ofEntries(Map.entry("first", "Alice"), Map.entry("last", "Smith")),
    Map.ofEntries(Map.entry("first", "Bob"), Map.entry("last", "Jones"))
};
    }
}
