(defparameter *my_data* (list
    (list (cons "type" "create") (cons "pr_id" "pr_1") (cons "draft" t))
    (list (cons "type" "create") (cons "pr_id" "pr_2"))
))
(setf *my_data* (list
    (list (cons "type" "create") (cons "pr_id" "pr_1") (cons "draft" t))
    (list (cons "type" "create") (cons "pr_id" "pr_2"))
))
