IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 F-TYPE PIC X(6) VALUE "create".
10 F-PR-ID PIC X(4) VALUE "pr_1".
10 F-DRAFT PIC X(5) VALUE "TRUE".
    05 FILLER.
10 F-TYPE PIC X(6) VALUE "create".
10 F-PR-ID PIC X(4) VALUE "pr_2".
PROCEDURE DIVISION.
    STOP RUN.
