using System.Collections.Generic;
using System;
var my_data = (
    new Dictionary<string, object> {["name"] = "Alice", ["age"] = 30},
    new Dictionary<string, object> {["name"] = "Bob", ["age"] = 25}
);
my_data = (
    new Dictionary<string, object> {["name"] = "Alice", ["age"] = 30},
    new Dictionary<string, object> {["name"] = "Bob", ["age"] = 25}
);
