import java.time.ZoneId
import java.time.ZonedDateTime
object Check {
var my_data = ZonedDateTime.of(2024, 1, 15, 12, 30, 0, 0, ZoneId.of("+00:00"))
my_data = ZonedDateTime.of(2024, 1, 15, 12, 30, 0, 0, ZoneId.of("+00:00"))
}
