import java.util.Map;
class Check {
    public static void check() {
var my_data = new Object[]{
    Map.ofEntries(Map.entry("key", "hello   world"), Map.entry("value", 1))
};
my_data = new Object[]{
    Map.ofEntries(Map.entry("key", "hello   world"), Map.entry("value", 1))
};
    }
}
