import Foundation
let my_data: Any = [
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": nil,
    "joined": DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15).date!,
    "last_login": DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15, hour: 12, minute: 30, second: 0).date!,
    "avatar": "48656c6c6f",
]
