IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC S9(18) COMP-5 VALUE 1000000.
    05 FILLER PIC S9(18) COMP-5 VALUE -1234.
    05 FILLER PIC S9(18) COMP-5 VALUE 255.
    05 FILLER PIC S9(18) COMP-5 VALUE -10.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
