my_data <- list(
    list("type" = "create", "pr_id" = "pr_1", "draft" = TRUE),
    list("type" = "create", "pr_id" = "pr_2")
)
my_data <- list(
    list("type" = "create", "pr_id" = "pr_1", "draft" = TRUE),
    list("type" = "create", "pr_id" = "pr_2")
)
