package main

func main() {
my_data := []map[string]any{
    {"type": "create", "pr_id": "pr_1", "draft": true},
    {"type": "create", "pr_id": "pr_2"},
}
my_data = []map[string]any{
    {"type": "create", "pr_id": "pr_1", "draft": true},
    {"type": "create", "pr_id": "pr_2"},
}
_ = my_data
}
