#lang racket
(define my_data (list
    (hash "type" "create" "pr_id" "pr_1" "draft" #t)
    (hash "type" "create" "pr_id" "pr_2")
))
(set! my_data (list
    (hash "type" "create" "pr_id" "pr_1" "draft" #t)
    (hash "type" "create" "pr_id" "pr_2")
))
