my $my_data = [
    {"first" => "Alice", "last" => "Smith"},
    {"first" => "Bob", "last" => "Jones"},
];
$my_data = [
    {"first" => "Alice", "last" => "Smith"},
    {"first" => "Bob", "last" => "Jones"},
];
