using System;
using System.Collections.Generic;
var my_data = new HashSet<DateOnly> {
    new DateOnly(2024, 1, 15),
    new DateOnly(2024, 6, 1)
};
my_data = new HashSet<DateOnly> {
    new DateOnly(2024, 1, 15),
    new DateOnly(2024, 6, 1)
};
