object Check {
var my_data = Map(
    // Configuration
    "name" -> "app",
    // Port setting
    "port" -> 3000,
)
my_data = Map(
    // Configuration
    "name" -> "app",
    // Port setting
    "port" -> 3000,
)
}
