use DateTime;
my $my_data = {
    "date" => DateTime->new(year => 2024, month => 1, day => 15),
    "datetime" => DateTime->new(year => 2024, month => 1, day => 15, hour => 12, minute => 30, second => 0, time_zone => 'UTC'),
};
$my_data = {
    "date" => DateTime->new(year => 2024, month => 1, day => 15),
    "datetime" => DateTime->new(year => 2024, month => 1, day => 15, hour => 12, minute => 30, second => 0, time_zone => 'UTC'),
};
