Imports System.Collections.Generic
Module Check
    Dim my_data = New Object() {
        New Dictionary(Of String, Object) From {{"first", "Alice"}, {"last", "Smith"}},
        New Dictionary(Of String, Object) From {{"first", "Bob"}, {"last", "Jones"}}
    }
End Module
