#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    @"line1
\nline2",
    @"line1
line2",
    @"",
];
my_data = @[
    @"line1
\nline2",
    @"line1
line2",
    @"",
];
    (void)my_data;
}
