IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER.
10 F-X PIC S9(18) COMP-5 VALUE 1.
10 F-Y COMP-2 VALUE 2.5.
    05 FILLER.
10 F-X PIC S9(18) COMP-5 VALUE 3.
10 F-Y COMP-2 VALUE 4.0.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
