#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    // Configuration
    @"name": @"app",
    // Port setting
    @"port": @(3000),
};
my_data = @{
    // Configuration
    @"name": @"app",
    // Port setting
    @"port": @(3000),
};
    (void)my_data;
}
