object Check {
var my_data = List[List[List[Int]]](
    List[List[Int]](List[Int](1, 2), List[Int](3, 4)),
    List[List[Int]](List[Int](5)),
)
my_data = List[List[List[Int]]](
    List[List[Int]](List[Int](1, 2), List[Int](3, 4)),
    List[List[Int]](List[Int](5)),
)
}
