import std.json;
void _check() {
auto my_data = JSONValue([
    JSONValue("2024-01-15"),
    JSONValue("2024-02-20"),
]);
my_data = JSONValue([
    JSONValue("2024-01-15"),
    JSONValue("2024-02-20"),
]);
}
