object Check {
var my_data = scala.collection.immutable.ListMap(
    "name" -> "Alice",
    "age" -> 30,
    "active" -> true,
)
my_data = scala.collection.immutable.ListMap(
    "name" -> "Alice",
    "age" -> 30,
    "active" -> true,
)
}
