using System.Collections.Generic;
var my_data = new Dictionary<string, string> {
    ["key"] = "it's here"  // a comment
};
my_data = new Dictionary<string, string> {
    ["key"] = "it's here"  // a comment
};
