import json
var my_data = %* [
    {"type": "create", "pr_id": "pr_1", "draft": "True"},
    {"type": "create", "pr_id": "pr_2"}
]
my_data = %* [
    {"type": "create", "pr_id": "pr_1", "draft": "True"},
    {"type": "create", "pr_id": "pr_2"}
]
