my_data = [
    Dict("type" => "create", "pr_id" => "pr_1", "draft" => true),
    Dict("type" => "create", "pr_id" => "pr_2"),
]
my_data = [
    Dict("type" => "create", "pr_id" => "pr_1", "draft" => true),
    Dict("type" => "create", "pr_id" => "pr_2"),
]
