class Check {
    public static void check() {
var my_data = new Object[]{
    new Object[]{new Object[]{}, new Object[]{}}
};
my_data = new Object[]{
    new Object[]{new Object[]{}, new Object[]{}}
};
    }
}
