using System.Collections.Generic;
var my_data = new Dictionary<string, string> {
    ["key"] = "\"bang!\""  // real
};
my_data = new Dictionary<string, string> {
    ["key"] = "\"bang!\""  // real
};
