my_data <- list(
    list(list("name" = "Alice"), list("name" = "Bob")),
    list(list("name" = "Charlie"), list("name" = "Dave"))
)
my_data <- list(
    list(list("name" = "Alice"), list("name" = "Bob")),
    list(list("name" = "Charlie"), list("name" = "Dave"))
)
