using System.Collections.Generic;
var my_data = new Dictionary<string, object> {
    // Configuration
    ["name"] = "app",
    // Port setting
    ["port"] = 3000
};
my_data = new Dictionary<string, object> {
    // Configuration
    ["name"] = "app",
    // Port setting
    ["port"] = 3000
};
