import java.time.ZoneId
import java.time.ZonedDateTime
object Check {
val my_data = List[ZonedDateTime](
    ZonedDateTime.of(2024, 1, 15, 12, 30, 0, 123456000, ZoneId.of("+00:00")),
    ZonedDateTime.of(2024, 6, 1, 8, 0, 0, 0, ZoneId.of("+00:00")),
)
}
