<?php
$my_data = [
    // Configuration
    "name" => "app",
    // Port setting
    "port" => 3000,
];
$my_data = [
    // Configuration
    "name" => "app",
    // Port setting
    "port" => 3000,
];
