import java.time.LocalDate
import java.time.LocalDateTime
var my_data = mapOf<String, Any?>(
    "date" to LocalDate.of(2024, 1, 15),
    "datetime" to LocalDateTime.of(2024, 1, 15, 12, 30, 0),
)
my_data = mapOf<String, Any?>(
    "date" to LocalDate.of(2024, 1, 15),
    "datetime" to LocalDateTime.of(2024, 1, 15, 12, 30, 0),
)
