object Check {
var my_data = List[List[Boolean]](
    List[Boolean](true, false),
    List[Boolean](true, true),
)
my_data = List[List[Boolean]](
    List[Boolean](true, false),
    List[Boolean](true, true),
)
}
