(defparameter *my_data* (list
    (list (cons "x" 1) (cons "y" 2.5))
    (list (cons "x" 3) (cons "y" 4.0))
))
(setf *my_data* (list
    (list (cons "x" 1) (cons "y" 2.5))
    (list (cons "x" 3) (cons "y" 4.0))
))
