object Check {
var my_data = Map(
    // Server configuration
    "host" -> "localhost",  // default host
    "port" -> 8080,
    // Enable debug mode
    "debug" -> true,
)
my_data = Map(
    // Server configuration
    "host" -> "localhost",  // default host
    "port" -> 8080,
    // Enable debug mode
    "debug" -> true,
)
}
