package main
import "time"

func main() {
my_data := time.Date(2024, time.January, 15, 12, 30, 45, 123456000, time.UTC)
my_data = time.Date(2024, time.January, 15, 12, 30, 45, 123456000, time.UTC)
_ = my_data
}
