object Check {
val my_data = List[List[Map[String, String]]](
    List[Map[String, String]](Map[String, String]("name" -> "Alice"), Map[String, String]("name" -> "Bob")),
    List[Map[String, String]](Map[String, String]("name" -> "Charlie"), Map[String, String]("name" -> "Dave")),
)
}
