using System.Collections.Generic;
var my_data = new Dictionary<string, string> {
    ["message"] = "no comment here"
};
my_data = new Dictionary<string, string> {
    ["message"] = "no comment here"
};
