import java.time.LocalDate
var my_data = setOf<LocalDate>(
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1),
)
my_data = setOf<LocalDate>(
    LocalDate.of(2024, 1, 15),
    LocalDate.of(2024, 6, 1),
)
