object Check {
var my_data = Map(
    "name" -> "Alice",
    "age" -> 30,
    "active" -> true,
    "score" -> null,
)
my_data = Map(
    "name" -> "Alice",
    "age" -> 30,
    "active" -> true,
    "score" -> null,
)
}
