var my_data = mapOf<String, String>(
    "key\nwith\nnewlines" to "value1",
    "key\twith\ttabs" to "value2",
    "" to "value3",
)
my_data = mapOf<String, String>(
    "key\nwith\nnewlines" to "value1",
    "key\twith\ttabs" to "value2",
    "" to "value3",
)
