import std.json;
void _check() {
auto my_data = JSONValue([
    // Configuration
    "name": JSONValue("app"),
    // Port setting
    "port": JSONValue(3000),
]);
my_data = JSONValue([
    // Configuration
    "name": JSONValue("app"),
    // Port setting
    "port": JSONValue(3000),
]);
}
