final my_data = {
    "name": "Alice",
    "age": 30,
    "active": true,
    "score": null,
    "joined": DateTime.parse("2024-01-15"),
    "last_login": DateTime.parse("2024-01-15T12:30:00+00:00"),
    "avatar": "48656c6c6f",
};
