object Check {
var my_data = List[Map[String, Double]](
    Map[String, Double]("x" -> 1, "y" -> 2.5),
    Map[String, Double]("x" -> 3, "y" -> 4.0),
)
my_data = List[Map[String, Double]](
    Map[String, Double]("x" -> 1, "y" -> 2.5),
    Map[String, Double]("x" -> 3, "y" -> 4.0),
)
}
