import java.time.Instant;
class Check {
    public static void check() {
var my_data = new Object[]{
    Instant.parse("2024-01-15T12:30:00.123456+00:00"),
    Instant.parse("2024-06-01T08:00:00+00:00")
};
    }
}
