import java.util.Map;
class Check {
    public static void check() {
var my_data = new Object[]{
    new Object[]{Map.ofEntries(Map.entry("name", "Alice")), Map.ofEntries(Map.entry("name", "Bob"))},
    new Object[]{Map.ofEntries(Map.entry("name", "Charlie")), Map.ofEntries(Map.entry("name", "Dave"))}
};
    }
}
