object Check {
var my_data = List[Map[String, String]](
    Map[String, String]("first" -> "Alice", "last" -> "Smith"),
    Map[String, String]("first" -> "Bob", "last" -> "Jones"),
)
my_data = List[Map[String, String]](
    Map[String, String]("first" -> "Alice", "last" -> "Smith"),
    Map[String, String]("first" -> "Bob", "last" -> "Jones"),
)
}
