(defparameter *my_data* (list
    ; Configuration
    (cons "name" "app")
    ; Port setting
    (cons "port" 3000)
))
(setf *my_data* (list
    ; Configuration
    (cons "name" "app")
    ; Port setting
    (cons "port" 3000)
))
