my_data = {
    struct('first', "Alice", 'last', "Smith"),
    struct('first', "Bob", 'last', "Jones")
};
my_data = {
    struct('first', "Alice", 'last', "Smith"),
    struct('first', "Bob", 'last', "Jones")
};
