object Check {
var my_data = Set[String](
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
)
my_data = Set[String](
    // before apple
    "apple",
    "banana",  // banana inline
    // trailing
)
}
