using Dates
Dict(
    "name" => "Alice",
    "age" => 30,
    "active" => true,
    "score" => nothing,
    "joined" => Date(2024, 1, 15),
    "last_login" => DateTime(2024, 1, 15, 12, 30, 0),
    "avatar" => "48656c6c6f",
)
