my_data = struct(
    'name', "Alice",
    'age', 30,
    'active', true,
    'score', [],
    'joined', datetime(2024, 1, 15),
    'last_login', datetime(2024, 1, 15, 12, 30, 0),
    'avatar', "48656c6c6f"
);
