object Check {
var my_data = Map(
    "users" -> List[Map[String, Any]](Map("name" -> "Bob", "tags" -> List[String]("admin", "user")), Map("name" -> "Carol", "tags" -> List[String]("guest"))),
)
my_data = Map(
    "users" -> List[Map[String, Any]](Map("name" -> "Bob", "tags" -> List[String]("admin", "user")), Map("name" -> "Carol", "tags" -> List[String]("guest"))),
)
}
