using System.Collections.Generic;
using System;
var my_data = (
    new Dictionary<string, object> {["key"] = "hello   world", ["value"] = 1}
);
my_data = (
    new Dictionary<string, object> {["key"] = "hello   world", ["value"] = 1}
);
