import Foundation
var my_data: Any = Set<AnyHashable>([
    DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15).date!,
    DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 6, day: 1).date!,
])
my_data = Set<AnyHashable>([
    DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 1, day: 15).date!,
    DateComponents(calendar: Calendar(identifier: .gregorian), year: 2024, month: 6, day: 1).date!,
])
