import java.time.LocalDateTime
var my_data = arrayOf(
    LocalDateTime.of(2024, 1, 15, 12, 30, 0),
    LocalDateTime.of(2024, 6, 1, 8, 0, 0),
)
my_data = arrayOf(
    LocalDateTime.of(2024, 1, 15, 12, 30, 0),
    LocalDateTime.of(2024, 6, 1, 8, 0, 0),
)
