IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 FILLER PIC X(12) VALUE "line1  line2".
    05 FILLER PIC X(11) VALUE "line1 line2".
    05 FILLER PIC X(1) VALUE "".
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
