using System.Collections.Generic;
using System;
var my_data = (
    ValueTuple.Create(),
    new Dictionary<string, object> {}
);
my_data = (
    ValueTuple.Create(),
    new Dictionary<string, object> {}
);
