local my_data = {
    [os.time({year = 2024, month = 1, day = 15, hour = 0, min = 0, sec = 0})] = true,
    [os.time({year = 2024, month = 6, day = 1, hour = 0, min = 0, sec = 0})] = true,
}
my_data = {
    [os.time({year = 2024, month = 1, day = 15, hour = 0, min = 0, sec = 0})] = true,
    [os.time({year = 2024, month = 6, day = 1, hour = 0, min = 0, sec = 0})] = true,
}
