use std::collections::HashMap;
fn main() {
    let my_data = HashMap::from([
        // Configuration
        ("name", "app"),
        // Port setting
        ("port", "3000"),
    ]);
    let _ = my_data;
}
