import java.util.Map;
class Check {
    public static void check() {
var my_data = Map.ofEntries(
    // Configuration
    Map.entry("name", "app"),
    // Port setting
    Map.entry("port", 3000)
);
my_data = Map.ofEntries(
    // Configuration
    Map.entry("name", "app"),
    // Port setting
    Map.entry("port", 3000)
);
    }
}
