using System.Collections.Generic;
using System;
var my_data = (
    new Dictionary<string, object> {["type"] = "create", ["pr_id"] = "pr_1", ["draft"] = true},
    new Dictionary<string, object> {["type"] = "create", ["pr_id"] = "pr_2"}
);
