Imports System.Collections.Generic
Module Check
    Dim my_data = New Object() {
        New Dictionary(Of String, Object) From {{"x", 1}, {"y", 2.5}},
        New Dictionary(Of String, Object) From {{"x", 3}, {"y", 4.0}}
    }
End Module
