use chrono::NaiveDate;
use chrono::NaiveDateTime;
use chrono::NaiveTime;
use std::collections::HashMap;
fn main() {
    {
        let my_data = HashMap::from([
            ("date", "2024-01-15"),
            ("datetime", "2024-01-15T12:30:00+00:00"),
        ]);
        let _ = my_data;
    }
    let my_data;
    my_data = HashMap::from([
        ("date", "2024-01-15"),
        ("datetime", "2024-01-15T12:30:00+00:00"),
    ]);
    let _ = my_data;
}
