import java.time.Instant;
class Check {
    public static void check() {
var my_data = Instant.parse("2024-01-15T12:30:00.123456+00:00");
my_data = Instant.parse("2024-01-15T12:30:00.123456+00:00");
    }
}
