import java.util.Set;
class Check {
    public static void check() {
var my_data = Set.of(
    "apple",
    "banana",
    "cherry"
);
my_data = Set.of(
    "apple",
    "banana",
    "cherry"
);
    }
}
