var my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("name" to "Alice", "age" to 30),
    mapOf<String, Any?>("name" to "Bob", "age" to 25),
)
my_data = listOf<Map<String, Any?>>(
    mapOf<String, Any?>("name" to "Alice", "age" to 30),
    mapOf<String, Any?>("name" to "Bob", "age" to 25),
)
