using System.Collections.Generic;
using System;
var my_data = new Dictionary<string, object> {
    ["name"] = "Alice",
    ["scores"] = (10, 20, 30)
};
my_data = new Dictionary<string, object> {
    ["name"] = "Alice",
    ["scores"] = (10, 20, 30)
};
