class Check {
    public static void check() {
var my_data = new String[]{
    // first
    "a",
    // second
    "b"
};
my_data = new String[]{
    // first
    "a",
    // second
    "b"
};
    }
}
