import java.util.Map;
class Check {
    public static void check() {
var my_data = Map.ofEntries(
    Map.entry("name", "Alice"),
    Map.entry("age", 30)
);
my_data = Map.ofEntries(
    Map.entry("name", "Alice"),
    Map.entry("age", 30)
);
    }
}
