fn main() {
    {
        let my_data = vec![
            // line 1
            // line 2
            "a",
        ];
        let _ = my_data;
    }
    let my_data;
    my_data = vec![
        // line 1
        // line 2
        "a",
    ];
    let _ = my_data;
}
