import json
var my_data = %* {
    "name": "Alice",
    "age": "30",
    "active": "True",
    "score": "None"
}
my_data = %* {
    "name": "Alice",
    "age": "30",
    "active": "True",
    "score": "None"
}
