#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @{
    @"name": @"Alice",
    @"age": @(30),
    @"active": @YES,
    @"score": [NSNull null],
    @"joined": @"2024-01-15",
    @"last_login": @"2024-01-15T12:30:00+00:00",
    @"avatar": @"48656c6c6f",
};
    (void)my_data;
}
