IDENTIFICATION DIVISION.
PROGRAM-ID. CHECK.
DATA DIVISION.
WORKING-STORAGE SECTION.
01 MY-DATA.
    05 F-A.
10 F-X PIC S9(18) COMP-5 VALUE 1.
    05 F-B PIC S9(18) COMP-5 VALUE 2.
PROCEDURE DIVISION.
    INITIALIZE MY-DATA.
    STOP RUN.
