import datetime
my_data = (
    datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=0, microsecond=123456),
    datetime.datetime(year=2024, month=6, day=1, hour=8, minute=0, second=0),
)
my_data = (
    datetime.datetime(year=2024, month=1, day=15, hour=12, minute=30, second=0, microsecond=123456),
    datetime.datetime(year=2024, month=6, day=1, hour=8, minute=0, second=0),
)
