package main

func main() {
my_data := []map[string]string{
    {"first": "Alice", "last": "Smith"},
    {"first": "Bob", "last": "Jones"},
}
my_data = []map[string]string{
    {"first": "Alice", "last": "Smith"},
    {"first": "Bob", "last": "Jones"},
}
_ = my_data
}
