using System.Collections.Generic;
using System;
var my_data = (
    new Dictionary<string, double> {["x"] = 1, ["y"] = 2.5},
    new Dictionary<string, double> {["x"] = 3, ["y"] = 4.0}
);
my_data = (
    new Dictionary<string, double> {["x"] = 1, ["y"] = 2.5},
    new Dictionary<string, double> {["x"] = 3, ["y"] = 4.0}
);
