#import <Foundation/Foundation.h>
void _check(void) {
id my_data = [NSSet setWithArray:@[
    @(1),
    @(2),
    @(3),
]];
my_data = [NSSet setWithArray:@[
    @(1),
    @(2),
    @(3),
]];
    (void)my_data;
}
