(defparameter *my_data* (list
    (list (list (cons "name" "Alice")) (list (cons "name" "Bob")))
    (list (list (cons "name" "Charlie")) (list (cons "name" "Dave")))
))
(setf *my_data* (list
    (list (list (cons "name" "Alice")) (list (cons "name" "Bob")))
    (list (list (cons "name" "Charlie")) (list (cons "name" "Dave")))
))
