Module Check
    Sub _declaration()
        Dim my_data = "2024-01-15T18:00:00+05:30"
    End Sub
    Sub _assignment()
        Dim my_data As Object
        my_data = "2024-01-15T18:00:00+05:30"
    End Sub
End Module
