import java.time.ZoneId
import java.time.ZonedDateTime
object Check {
var my_data = ZonedDateTime.of(2024, 1, 15, 12, 30, 45, 123456000, ZoneId.of("UTC"))
my_data = ZonedDateTime.of(2024, 1, 15, 12, 30, 45, 123456000, ZoneId.of("UTC"))
}
