(defparameter *my_data* (list
    (list (cons "first" "Alice") (cons "last" "Smith"))
    (list (cons "first" "Bob") (cons "last" "Jones"))
))
(setf *my_data* (list
    (list (cons "first" "Alice") (cons "last" "Smith"))
    (list (cons "first" "Bob") (cons "last" "Jones"))
))
