#import <Foundation/Foundation.h>
void _check(void) {
id my_data = @[
    @{@"type": @"create", @"pr_id": @"pr_1", @"draft": @YES},
    @{@"type": @"create", @"pr_id": @"pr_2"},
];
    (void)my_data;
}
